/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.webservices.listener;

import java.io.File;

import javax.jws.WebService;

import org.apache.commons.io.FileUtils;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.util.ResourceUtil;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.services.UnexpectedException;
import org.ow2.weblab.webservices.listener.bean.FolderListenerConfigBean;

/**
 * WebLab Resource Crawler fork from old folder-resource-iterator service.
 * 
 * @author asaval, jdoucy, ymombrun
 */
@WebService(endpointInterface = "org.ow2.weblab.core.services.QueueManager")
public class WebLabResourceCrawler extends DefaultFolderListener {


	protected final WebLabMarshaller marshaller;


	public WebLabResourceCrawler(final FolderListenerConfigBean listenerConfigBean) {
		super(listenerConfigBean);
		this.marshaller = new WebLabMarshaller();
	}


	@Override
	protected Resource createResource(final File file, final String usageContext) throws UnexpectedException {
		this.log.debug("Try unmarshall file '" + file.getAbsolutePath() + "'.");
		// Unmarshal the resource
		final Resource res;
		try {
			res = this.marshaller.unmarshal(file, Resource.class);
		} catch (final WebLabCheckedException wlce) {
			throw new UnexpectedException("Could not unmarshall " + file.getAbsolutePath(), wlce);
		}

		// Log it only in trace mode
		if (this.log.isTraceEnabled()) {
			try {
				this.log.trace(ResourceUtil.saveToXMLString(res));
			} catch (final WebLabCheckedException wlce) {
				this.log.warn("Could not log the resource.", wlce);
			}
		}

		// Remove file if needed.
		if (this.conf.isDelete()) {
			this.log.debug("Try remove file '" + file.getAbsolutePath() + "'.");
			FileUtils.deleteQuietly(file);
		}

		return res;
	}

}
