/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2012 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.webservices.listener.tool;

import java.io.File;
import java.util.Collection;
import java.util.regex.Pattern;

import org.apache.commons.io.monitor.FileAlterationListener;
import org.apache.commons.io.monitor.FileAlterationObserver;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;


/**
 * @author Jérémie Doucy
 */
public class FifoFileListener implements FileAlterationListener {


	protected final Pattern fileUrlPattern;


	protected final Log log;


	protected final Collection<File> fifo;


	public FifoFileListener(final Collection<File> fifo, final Pattern fileUrlPattern) {
		this.fifo = fifo;
		this.fileUrlPattern = fileUrlPattern;
		this.log = LogFactory.getLog(this.getClass());
	}


	@Override
	public void onStart(final FileAlterationObserver observer) {
		// nothing to do
	}


	@Override
	public void onDirectoryCreate(final File directory) {
		// nothing to do
		this.notTakeIntoAccount("A directory has been created (" + directory.getAbsolutePath() + ").");
	}


	@Override
	public void onDirectoryChange(final File directory) {
		// nothing to do
		this.notTakeIntoAccount("A directory has been changed (" + directory.getAbsolutePath() + ").");
	}


	@Override
	public void onDirectoryDelete(final File directory) {
		// nothing to do
		this.notTakeIntoAccount("A directory has been deleted (" + directory.getAbsolutePath() + ").");
	}


	@Override
	public void onFileCreate(final File file) {
		if (this.fileUrlPattern.matcher(file.getAbsolutePath()).matches()) {
			this.log.debug("Adding file: " + file + " to the FIFO.");
			this.fifo.add(file);
		} else {
			this.log.info("File: " + file + " not added to the FIFO due to none pattern match: " + this.fileUrlPattern);
		}
	}


	@Override
	public void onFileChange(final File file) {
		// nothing to do
		this.notTakeIntoAccount("A file has just changed (" + file.getAbsolutePath() + ").");
	}


	@Override
	public void onFileDelete(final File file) {
		/*
		 * impossible
		 */
		if (this.fifo.contains(file)) {
			this.log.debug("Remove file: " + file + " from the FIFO.");
			this.fifo.remove(file);
		}

	}


	@Override
	public void onStop(final FileAlterationObserver observer) {
		// nothing to do
	}


	protected void notTakeIntoAccount(final String reason) {
		this.log.debug(reason + " This is not taken into account.");

	}

}
